==> oji-3.0.0.tgz: package/README.md <==
<p align="center">
  <img src="https://i.imgur.com/2fhhLzH.gif" href="" height="256">
  <h2 align="center">OJI</h2>
  <p align="center">(◕‿◕) Text Emoticons Maker<p>
  
<p align="center">
<a href="https://www.npmjs.com/package/oji"><img src="https://badge.fury.io/js/oji.svg" alt="npm Package"></a>  
<a href="https://travis-ci.org/xxczaki/oji"><img src="https://travis-ci.org/xxczaki/oji.svg?branch=master" alt="Build Status"></a> 
<a href="https://github.com/sindresorhus/xo"><img src="https://img.shields.io/badge/code_style-XO-5ed9c7.svg" alt="XO Code Style"></a>
<a href="https://www.youtube.com/watch?v=9auOCbH5Ns4"><img src="https://img.shields.io/badge/unicorn-approved-ff69b4.svg" alt="Unicorn Approved"></a>
  </p>
  
<p align="center"><img src="https://i.imgur.com/FUaVbLd.gif" alt="GIF"></p>
<h5 align="center"><a href="https://www.producthunt.com/posts/oji">Discuss it on Product Hunt! :rocket:</a></h5>

## :floppy_disk: Installation

``` bash
npm i -g oji
```
<a href="https://www.patreon.com/akepinski">
	<img src="https://c5.patreon.com/external/logo/become_a_patron_button@2x.png" width="160">
</a>

## :feet: Usage

Just type `oji` to start interactive emoticon creator! Works on every platform :unicorn:

## :package: npm Dependencies [![Known Vulnerabilities](https://snyk.io/test/github/xxczaki/oji/badge.svg)](https://snyk.io/test/github/xxczaki/oji)

- [inquirer](https://www.npmjs.com/package/inquirer)
- [clipboardy](https://www.npmjs.com/package/clipboardy)
- [opn](https://www.npmjs.com/package/opn)
- [chalk](https://www.npmjs.com/package/chalk)
- [xo](https://www.npmjs.com/package/xo)

## :warning: Note

Node.js >= 6 is required!

## :nerd_face: Author

[![Antoni Kepinski](https://github.com/xxczaki.png?size=100)](https://akepinski.me)
---|
[Antoni Kepinski :rocket:](https://akepinski.me)

## :clipboard: License

MIT © [Antoni Kepinski](https://akepinski.me)

[![FOSSA Status](https://app.fossa.io/api/projects/git%2Bgithub.com%2Fxxczaki%2Foji.svg?type=large)](https://app.fossa.io/projects/git%2Bgithub.com%2Fxxczaki%2Foji?ref=badge_large)

==> oji-3.0.1.tgz: package/README.md <==
<p align="center">
  <img src="https://i.imgur.com/2fhhLzH.gif" href="" height="256">
  <h2 align="center">OJI</h2>
  <p align="center">(◕‿◕) Text Emoticons Maker<p>
  
<p align="center">
<a href="https://travis-ci.org/xxczaki/oji"><img src="https://travis-ci.org/xxczaki/oji.svg?branch=master" alt="Build Status"></a> 
<a href="https://ci.appveyor.com/project/xxczaki/oji"><img src="https://ci.appveyor.com/api/projects/status/sbxv43mauvm359av?svg=true" alt="AppVeyor Build Status"></a>
<a href="https://github.com/sindresorhus/xo"><img src="https://img.shields.io/badge/code_style-XO-5ed9c7.svg" alt="XO Code Style"></a>
<a href="https://www.youtube.com/watch?v=9auOCbH5Ns4"><img src="https://img.shields.io/badge/unicorn-approved-ff69b4.svg" alt="Unicorn Approved"></a>
  </p>
  
<p align="center"><img src="https://i.imgur.com/Ilh90oI.gif" alt="GIF"></p>
<h5 align="center"><a href="https://www.producthunt.com/posts/oji">Discuss it on Product Hunt! :rocket:</a></h5>

## :floppy_disk: Installation

``` bash
npm i -g oji
```
<a href="https://www.patreon.com/akepinski">
	<img src="https://c5.patreon.com/external/logo/become_a_patron_button@2x.png" width="160">
</a>

## :feet: Usage

Just type `oji` to start interactive emoticon creator! Works on every platform :unicorn:

## :package: npm Dependencies [![Known Vulnerabilities](https://snyk.io/test/github/xxczaki/oji/badge.svg)](https://snyk.io/test/github/xxczaki/oji)

- [inquirer](https://www.npmjs.com/package/inquirer)
- [clipboardy](https://www.npmjs.com/package/clipboardy)
- [opn](https://www.npmjs.com/package/opn)
- [log-symbols](https://www.npmjs.com/package/log-symbols)
- [chalk](https://www.npmjs.com/package/chalk)
- [xo](https://www.npmjs.com/package/xo)

## :warning: Note

Node.js >= 6 is required!

## :nerd_face: Author

[![Antoni Kepinski](https://github.com/xxczaki.png?size=100)](https://akepinski.me)
---|
[Antoni Kepinski :rocket:](https://akepinski.me)

## :clipboard: License

MIT © [Antoni Kepinski](https://akepinski.me)

[![FOSSA Status](https://app.fossa.io/api/projects/git%2Bgithub.com%2Fxxczaki%2Foji.svg?type=large)](https://app.fossa.io/projects/git%2Bgithub.com%2Fxxczaki%2Foji?ref=badge_large)
